@@ -1,5 +1,5 @@
 import pandas as pd
-from multiprocess import Pool
+from multiprocessing import Pool
 import functools
 from os import cpu_count
 
@@ -15,12 +15,12 @@ def df_apply_parallel(self, func, *static_data, num_processes=cpu_count(), **kwa
 
     Return
         Result as Series that can be stored in new column.
-    """          
-    
+    """
+
     func = functools.partial(func, *static_data, **kwargs)
     with Pool(num_processes) as p:
         ret_list = p.map(func, [row for _, row in self.iterrows()])
 
     return pd.Series(ret_list, index=self.index)
 
-pd.core.frame.DataFrame.apply_parallel = df_apply_parallel
\ No newline at end of file
+pd.core.frame.DataFrame.apply_parallel = df_apply_parallel
